@@ -8,30 +8,27 @@ class GlobalAveragePooling2D(layers.Layer):
     """ Quantization aware GlobalAveragePooling2D. """
 
     def __init__(
-        self, num_bits=4, **kwargs,
+        self,
+        num_bits=4,
+        **kwargs,
     ):
         super().__init__(**kwargs)
         self.num_bits = num_bits
 
     def build(self, input_shape):
-        unused_N, unused_C, H, W = input_shape
-        assert H in [2, 4, 8, 16] and W in [
-            2,
-            4,
-            8,
-            16,
-        ], "input_shape must in [2,4,8,16], but {} is not.".format((H, W,))
-        self.origin_shape = H, W
+        pass
 
     def call(self, inputs):
         x = tf.reduce_mean(inputs, axis=[2, 3])
-        x = fake_quant._fake_quant(x, self.num_bits)
+        x = fake_quant.fake_quant_activation(x, multiplier=1, num_bits=self.num_bits)
         return x
 
     def get_config(self):
         config = super().get_config()
         config.update(
-            {"num_bits": self.num_bits,}
+            {
+                "num_bits": self.num_bits,
+            }
         )
         return config
 
